@@ -22,6 +22,7 @@
 #include "libs/fvwmlib.h"
 #include "libs/charmap.h"
 #include "libs/wcontext.h"
+#include "libs/Grab.h"
 #include "fvwm.h"
 #include "externs.h"
 #include "execcontext.h"
@@ -74,6 +75,8 @@ static void init_style(
 	/* determine level of decoration */
 	setup_style_and_decor(t, pstyle, pbuttons);
 	/* restore some old values */
+	IS_STICKY_ACROSS_PAGES(t) = IS_STICKY_ACROSS_PAGES(old_t);
+	IS_STICKY_ACROSS_DESKS(t) = IS_STICKY_ACROSS_DESKS(old_t);
 	GET_USER_STATES(t) = GET_USER_STATES(old_t);
 
 	return;
@@ -568,7 +571,7 @@ static void apply_window_updates(
 			refresh_window(FW_W_FRAME(t), False);
 		}
 	}
-	t->shade_anim_steps = pstyle->shade_anim_steps;
+	setup_numeric_vals(t, pstyle);
 	if (flags->do_update_cr_motion_method)
 	{
 		switch (SCR_MOTION_METHOD(&pstyle->flags))
